#
#  Name:    MpScan.py
#
#  Purpose: This Python module implements some utility functions for
#           manipulating MX scans.
#
#  Author:  William Lavender
#
#-----------------------------------------------------------------------
#
#  Copyright 2002, 2004-2005 Illinois Institute of Technology
#
#  See the file "LICENSE" for information on usage and redistribution
#  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#

import Mp

#
#  Load a file of scan records into the current database.
#

def load_scans( record_list, filename ):

	file = open( filename, "r" )

	while ( 1 ):

		### Read in a record description. ###

		description = file.readline()

		### If we are at EOF, exit the while loop. ###

		if ( len( description ) == 0 ):
			break

		### What is the name of the record we are trying to create? ###

		description_list = description.split()
		record_name = description_list[0]

		### Does a record by this name already exist? ###

		continue_statement = 0	# This is bogus.

		try:
			old_record = record_list.get_record( record_name )

			### Is the old record a scan record? ###

			superclass = old_record.get_field( "mx_superclass" )

			### If so delete it, otherwise skip it. ###

			if ( superclass == "scan" ):
				old_record.delete_record()
			else:
				t = "Skipping scan '%s' from file '%s'.  "
				t = t + "Only preexisting records that are "
				t = t + "scan records may be replaced."

				Mp.warning( t % ( record_name, filename ) )

				continue_statement = 1	# This is also bogus.
		except:
			pass

		### The following offense against nature is due to the fact
		### that Python does not allow 'continue' inside a try
		### statement.  A footnote in Python's language reference
		### manual says that this restriction is due to the
		### "implementer's laziness" (!?!?!!!)
		### ( Insert unprintable comment here. )

		if ( continue_statement ):
			continue

		### Now create the scan record. ###

		new_record = \
		    record_list.create_record_from_description( description )

		new_record.finish_record_initialization()

	### We are done so close the file. ###

	file.close()

#
#  Save all the scans in the current database to a file.
#

def save_scans( record_list, filename ):

	file = open( filename, "w" )

	### Get the list head record.  It is called 'mx_database'. ###

	try:
		list_head_record = record_list.get_record( "mx_database" )
	except:
		t = "The 'record_list' object passed to 'save_scans' "
		t = t + "is not a valid Mp.RecordList.  "
		t = t + "This is probably due to an error in the program "
		t = t + "that called 'save_scans'."

		raise Mp.Illegal_Argument_Error, t
		return

	### Loop through the current database looking for scan records. ###

	current_record = list_head_record.get_next_record()

	while ( current_record is not list_head_record ):

		superclass = current_record.get_field( "mx_superclass" )

		if ( superclass == "scan" ):
			description = \
				current_record.create_description_from_record()

			file.write( description + "\n" )

		current_record = current_record.get_next_record()

	file.close()

	record_list._unsaved_scans = 0

